@@ -127,6 +127,18 @@ function(x)
                genome = if (is.null(contig$assembly)) NA else contig$assembly)
 })
 
+## vcfFields
+setMethod("vcfFields", "VCFHeader", function(x, ...)
+{
+    fixed <- names(fixed(x))
+    if (!is.null(fixed)) fixed <- c("REF", "ALT", "QUAL", "FILTER")
+    CharacterList(fixed = fixed,
+                  info = rownames(info(x)),
+                  geno = rownames(geno(x)),
+                  samples = samples(x)
+                  )
+})
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Show
 ###
